%global pkgname edim

Name:           gap-pkg-%{pkgname}
Version:        1.3.3
Release:        2%{?dist}
Summary:        Elementary divisors of integer matrices

# doc/mathml.css is MPLv1.1; all other files are GPLv2+
License:        GPLv2+ and MPLv1.1
URL:            http://www.math.rwth-aachen.de/~Frank.Luebeck/EDIM/
Source0:        http://www.math.rwth-aachen.de/~Frank.Luebeck/EDIM/%{pkgname}-%{version}.tar.bz2

BuildRequires:  gap-devel
BuildRequires:  GAPDoc-latex
BuildRequires:  gcc

Requires:       gap-core

%description
The main purpose of the EDIM package is to publish an implementation of
an algorithm (found by the package author) for computing prime parts of
the elementary divisors of integer matrices (i.e., the diagonal entries
of the Smith normal form).

The programs are developed and already successfully used for large
matrices (up to rank >12000) with moderate entries and many non-trivial
elementary divisors which are products of some small primes. But they
should be useful for other types of matrices as well.

Among the other functions of the package are:
- an inversion algorithm for large rational matrices (using a p-adic
  method)
- a program for finding the largest elementary divisor of an integral
  matrix (particularly interesting when this is much smaller than the
  determinant) and
- implementations of some normal form algorithms described by Havas,
  Majewski, Matthews, Sterling (using LLL- or modular techniques).

%prep
%setup -q -n EDIM-%{version}

# Fix encodings
for fil in doc/edim.bib doc/edim.bbl; do
  iconv -f iso8859-1 -t utf-8 $fil > $fil.utf8
  touch -r $fil $fil.utf8
  mv -f $fil.utf8 $fil
done

%build
export LC_ALL=C.UTF-8

# This is NOT an autoconf-generated script.  Do not use %%configure.
./configure %{_gap_dir}
make %{?_smp_mflags}
chmod 0755 bin/*/ediv.so

# Link to main GAP documentation
ln -s %{_gap_dir}/doc ../../doc
mkdir ../pkg
ln -s ../EDIM-%{version} ../pkg
gap -l "$PWD/..;%{_gap_dir}" makedocrel.g < /dev/null
rm -f ../../doc
rm -fr ../pkg

%install
mkdir -p %{buildroot}%{_gap_dir}/pkg
cp -a ../EDIM-%{version} %{buildroot}%{_gap_dir}/pkg/%{pkgname}
rm -f %{buildroot}%{_gap_dir}/pkg/%{pkgname}/{doc/clean,CHANGES,configure,GPL,Makefile*,README}
rm -f %{buildroot}%{_gap_dir}/pkg/%{pkgname}/doc/*.{aux,bbl,blg,brf,idx,ilg,ind,log,out,pnr,toc}
rm -fr %{buildroot}%{_gap_dir}/pkg/%{pkgname}/src

%check
export LC_ALL=C.UTF-8
gap -q -l "%{buildroot}%{_gap_dir};%{_gap_dir}" < tst/test.g 2>&1 | tee log
grep -Fvq 'false' log
rm -f log

%files
%doc CHANGES README
%license GPL
%docdir %{_gap_dir}/pkg/%{pkgname}/doc
%docdir %{_gap_dir}/pkg/%{pkgname}/htm
%{_gap_dir}/pkg/%{pkgname}/

%changelog
* Fri Jul 13 2018 Fedora Release Engineering <releng@fedoraproject.org> - 1.3.3-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_29_Mass_Rebuild

* Sat Mar 17 2018 Jerry James <loganjerry@gmail.com> - 1.3.3-1
- New upstream version

* Wed Feb 07 2018 Fedora Release Engineering <releng@fedoraproject.org> - 1.3.2-9
- Rebuilt for https://fedoraproject.org/wiki/Fedora_28_Mass_Rebuild

* Wed Aug 02 2017 Fedora Release Engineering <releng@fedoraproject.org> - 1.3.2-8
- Rebuilt for https://fedoraproject.org/wiki/Fedora_27_Binutils_Mass_Rebuild

* Wed Jul 26 2017 Fedora Release Engineering <releng@fedoraproject.org> - 1.3.2-7
- Rebuilt for https://fedoraproject.org/wiki/Fedora_27_Mass_Rebuild

* Fri Feb 10 2017 Fedora Release Engineering <releng@fedoraproject.org> - 1.3.2-6
- Rebuilt for https://fedoraproject.org/wiki/Fedora_26_Mass_Rebuild

* Thu Apr  7 2016 Jerry James <loganjerry@gmail.com> - 1.3.2-5
- Rebuild for gap 4.8.3

* Wed Feb 03 2016 Fedora Release Engineering <releng@fedoraproject.org> - 1.3.2-4
- Rebuilt for https://fedoraproject.org/wiki/Fedora_24_Mass_Rebuild

* Wed Nov 11 2015 Jerry James <loganjerry@gmail.com> - 1.3.2-3
- Drop scriptlets; gap-core now uses rpm file triggers
- Rebuild documentation from source
- Turn test failures into build failures

* Wed Jun 17 2015 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.3.2-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_23_Mass_Rebuild

* Wed May 20 2015 Jerry James <loganjerry@gmail.com> - 1.3.2-1
- Initial RPM (bz 1223627)
